@@ -25,7 +25,8 @@
 #            |- RightsError
 #            |- GraphError
 #            |- FilterError
-
+#            |- CubeError
+#            |- DecodeError
 
 class PolymaticaException(Exception):
     """
@@ -132,3 +133,13 @@ class GraphError(PolymaticaException):
 class FilterError(PolymaticaException):
     """ Ошибки фильтрации """
     pass
+
+
+class CubeError(PolymaticaException):
+    """ Ошибки кубов (мультисфер) """
+    pass
+
+
+class DecodeError(PolymaticaException):
+    """ Ошибки кодировки/декодирования """
+    pass
