@@ -3,27 +3,21 @@
 """
 Описание интерфейсного класса, предназначенного для внешних вызовов.
 """
-from typing import Any, Union
-from ..common import GRAPH_ID
+from typing import Any, List, Union
+from ..common import GRAPH_ID, business_logic, graph
 from .types import Lines, Cylinders, CumulativeCylinders, Point, PointSeries, Chord, Sankey, \
     Circles, CirclesSeries, Radar, Pools, Pools3D, Balls, Areas, CumulativeAreas, Pies, Graph, Surface, Corridors
 
-# перечисление типов уже реализованных графиков
-# нужно для того, чтобы пользователь не смог вызвать ещё не существующие графики
-# подлежит удалению, когда все типы графиков будут реализованы (ID-3190)
-IMPLEMENTED_GRAPHS = ['lines', 'cylinders', 'cumulative_cylinders', 'point', 'point_series', 'chord', 'sankey',
-        'radar', 'circles', 'circles_series', 'balls', 'pools', '3d_pools', 'pies', 'areas', 'cumulative_areas']
 
-class Graph():
-    """Класс, реализующий методы для взаимодействия пользователя с графиками"""
-    def __init__(self, base_bl: 'BusinessLogic', graph_type: Union[int, str], settings: str, grid: int,
-                labels: dict, other: dict, current_id: str):
+class IGraph():
+    """Класс, реализующий интерфейс взаимодействия пользователя с графиками"""
+    def __init__(self, base_bl: business_logic, graph_type: Union[int, str], settings: str, grid: int,
+                labels: dict, other: dict, current_id: str, m_size: dict):
         # экземпляр класса BusinessLogic
         self._base_bl = base_bl
         # тип графика (в виде строки), задающийся пользователем; если заданного типа не существует -
         # будет сгенерирована ошибка; является общим параметром для всех типов графиков
         self._graph_type = self._get_graph_type(graph_type)
-        self._check_implemented()
         # проверка заданного типа графика на принадлежность заданной версии Полиматики
         self._check_polymatica_version()
         # тип строящегося графика, принимаемый Полиматикой
@@ -44,6 +38,9 @@ class Graph():
         self._other = other
         # идентификатор мультисферы (если график создаётся) или идентификатор графика (если график изменяется)
         self._current_id = current_id
+        # настройки ширины/высоты окна
+        self._check_type(m_size, dict, 'm_size')
+        self._m_size = m_size
 
     def _get_graph_type(self, graph_type: Union[int, str]) -> str:
         """
@@ -81,14 +78,6 @@ class Graph():
         else:
             raise ValueError('Param "g_type" must be string or int!')
 
-    def _check_implemented(self):
-        """
-        Временная проверка, показывающая, реализован ли на данный момент указанный тип графика.
-        Будет удалено, когда будут реализованы все 19 типов графиков.
-        """
-        if self._graph_type not in IMPLEMENTED_GRAPHS:
-            raise ValueError('Type "{}" of graph is not yet implemented!'.format(self._graph_type))
-
     def _check_polymatica_version(self):
         """
         Проверка заданного типа графики на совместимость с версией Полиматики.
@@ -143,7 +132,7 @@ class Graph():
         }
         return version_plot_map.get(self._base_bl.polymatica_version).get(self._graph_type)
 
-    def _get_graph_instance(self) -> 'Graph instance':
+    def _get_graph_instance(self) -> graph:
         """
         Возвращает необходимый класс в зависимости от типа графика.
         """
@@ -279,6 +268,22 @@ class Graph():
                 break
         return config
 
+    def _get_size_param(self, fields: List, min_value: int, default: int) -> int:
+        """
+        Проверка значения заданной размерности на соответствие минимальному значению. Если проверка не пройдена -
+        будет сгенерирована ошибка.
+        :param fields: (list) список ключей, по которым можно извлечь необходимую размерность;
+            гарантированно содержит только два элемента: на первом месте - полное наименование параметра (height/width),
+            на втором - сокращённое (h/w).
+        :param min_value: (int) минимальное значение заданной размерности.
+        :param default: (int) значение по-умолчанию, если заданная размерность не указана.
+        :return: (int) размер окна для заданной размерности (высота, ширина).
+        """
+        size_value = self._m_size.get(fields[0], self._m_size.get(fields[1], default))
+        if size_value < min_value:
+            raise ValueError('Value of parameter "{}" is below the minimum ({})!'.format(fields[0], min_value))
+        return size_value
+
     def create(self) -> str:
         """
         Создание нового графика с заданными параметрами.
@@ -303,16 +308,21 @@ class Graph():
         )
         graph_module_uuid = self._base_bl.h.parse_result(res, 'module_desc', 'uuid')
 
-        # запаковываем в словарь все необходимые данные, в т.ч. конфигурацию OLAP-модуля
-        common_params = {
-            'olap_module_id': olap_module_id,
-            'graph_module_id': graph_module_uuid,
-            'olap_config': self._get_olap_module_config(olap_module_id)
-        }
-
-        # отрисовываем график на созданном окне
+        # определяем тип конкретного графика
         graph = self._get_graph_instance()
         try:
+            # запаковываем в словарь все необходимые данные, в т.ч. конфигурацию OLAP-модуля
+            common_params = {
+                'olap_module_id': olap_module_id,
+                'graph_module_id': graph_module_uuid,
+                'olap_config': self._get_olap_module_config(olap_module_id),
+                'module_size': {
+                    'height': self._get_size_param(['height', 'h'], 240, 540),
+                    'width': self._get_size_param(['width', 'w'], 840, 840)
+                }
+            }
+
+            # отрисовываем график на созданном окне
             graph(
                 self._base_bl,
                 self._settings,
@@ -322,7 +332,7 @@ class Graph():
                 common_params,
                 self._plot_type
             ).draw()
-        except Exception as ex:
+        except Exception:
             # если не удалось отрисовать график с заданными параметрами - закрываем созданное окно графиков
             self._base_bl.execute_manager_command(
                 command_name='user_iface', state='close_module', module_id=graph_module_uuid)
@@ -355,16 +365,21 @@ class Graph():
         if not olap_module_id:
             raise ValueError('OLAP module for graph "{}" not found!'.format(graph_module_id))
 
-        # запаковываем в словарь все необходимые данные, в т.ч. конфигурацию OLAP-модуля
-        common_params = {
-            'olap_module_id': olap_module_id,
-            'graph_module_id': graph_module_id,
-            'olap_config': self._get_olap_module_config(olap_module_id)
-        }
-
-        # отрисовываем график на созданном окне
+        # определяем тип конкретного графика
         graph = self._get_graph_instance()
         try:
+            # запаковываем в словарь все необходимые данные, в т.ч. конфигурацию OLAP-модуля
+            common_params = {
+                'olap_module_id': olap_module_id,
+                'graph_module_id': graph_module_id,
+                'olap_config': self._get_olap_module_config(olap_module_id),
+                'module_size': {
+                    'height': self._get_size_param(['height', 'h'], 240, 540),
+                    'width': self._get_size_param(['width', 'w'], 840, 840)
+                }
+            }
+
+            # отрисовываем график на созданном окне
             graph(
                 self._base_bl,
                 self._settings,
@@ -374,7 +389,7 @@ class Graph():
                 common_params,
                 self._plot_type
             ).draw()
-        except Exception as ex:
+        except Exception:
             # если не удалось отрисовать график с заданными параметрами - закрывать созданное окно графиков не нужно,
             # т.к. оно уже было создано ранее (не в этом методе)
             raise
