@@ -4,9 +4,10 @@
 
 from typing import Any, List, Dict, Tuple
 from itertools import count
+from datetime import datetime
 import time
 from .exceptions import ParseError, ScenarioError, PolymaticaException
-from .common import raise_exception, FUNCS
+from .common import raise_exception, FUNCS, MEASURE_STR_INT_TYPES_MAP
 
 class Helper:
     def __init__(self, sc):
@@ -106,33 +107,16 @@ class Helper:
         :param name: (str) вид факта (в строковом представлении)
         :return: (int) целочисленный вид факта.
         """
-        measure_types = {
-            "Значение": 0,
-            "Процент": 1,
-            "Ранг": 2,
-            "Количество уникальных": 3,
-            "Среднее": 4,
-            "Отклонение": 5,
-            "Минимум": 6,
-            "Максимум": 7,
-            "Изменение": 8,
-            "Изменение в %": 9,
-            "Нарастающее": 10,
-            "ABC": 11,
-            "Медиана": 12,
-            "Количество": 13,
-            "UNKNOWN": 14
-        }
-        if name not in measure_types:
+        if name not in MEASURE_STR_INT_TYPES_MAP:
             return self._raise_exception(ValueError, "No such measure type: {}".format(name), with_traceback=False)
-        return measure_types[name]
+        return MEASURE_STR_INT_TYPES_MAP[name]
 
     def parse_formula(self, formula: str) -> List:
         """
         Парсинг формулы для создания вычислимого факта.
         Разбивает исходную формулу на составляющие, при этом склеивая названия фактов, содержащие пробелы.
         Примеры:
-            1. "5 + [Сумма] * 2 + corr([Сумма];[ID])" -> ["5", "+", "[Сумма]", "*", "2", "+", "corr([Сумма];[ID])"]
+            1. "5 + [Сумма&Март] * 2 + corr([Сумма];[ID])" -> ["5", "+", "[Сумма&Март]", "*", "2", "+", "corr([Сумма];[ID])"]
             2. "top([Сумма по всем отделам]; 10) >= 94" -> ["top([Сумма по всем отделам]; 10)", ">=", "94"]
         :param formula: (str) исходная формула.
         :return: (List) составляющие исходной формулы.
@@ -287,6 +271,41 @@ class Helper:
             data = self.parse_result(result=result, key="data")
         return result
 
+    def get_pretty_size(self, num_bytes: int, presicion: int = 1, units_lang: str = 'ru') -> str:
+        """
+        Перевод значения в байтах в более крупные единицы измерения.
+        :param num_bytes: (int) исходный размер в байтах.
+        :param presicion: (int) точность; количество знаков после запятой; по-умолчанию 1.
+        :param units_lang: (str) язык отображения размерностей; доступны варианты "ru", "en".
+        :return: (str) человеко-читабельная запись исходного размера в байтах; например: "3.5 MB", "7 bytes".
+        """
+        if units_lang == 'ru':
+            units = ['байт', 'Кбайт', 'Мбайт', 'Гбайт', 'Тбайт']
+        elif units_lang == 'en':
+            units = ['bytes', 'kB', 'MB', 'GB', 'TB']
+        else:
+            raise ValueError('Wrong "units_lang" param: "{}"! Available: "ru", "en".')
+
+        len_units = len(units)
+        # предел; число, после которого единицы измерения переходят на уровень выше
+        threshold = 1024
+        for i in range(0, len_units):
+            if num_bytes < threshold:
+                return '{:g} {}'.format(num_bytes, units[i])
+            if i == len_units - 1:
+                break
+            num_bytes = round(num_bytes / threshold, presicion)
+        return '{:g} {}'.format(num_bytes, units[-1])
+
+    def get_datetime_from_timestamp(self, timestamp: int, mask: str = r'%d.%m.%Y %H:%M') -> str:
+        """
+        Получение даты-времени в человеко-читаемом виде из исходного числа секунд (таймстампа).
+        :param timestamp: (int) количество секунд.
+        :param mask: (str) маска перевода в формат даты-времени.
+        :return: (str) значение даты-времени в человеко-читаемом виде.
+        """
+        return datetime.fromtimestamp(int(timestamp/10**6)).strftime(mask)
+
     def get_filter_rows(self, dim_id: str) -> Dict:
         """
         Загрузить строки и колонки мультисферы
