@@ -4,12 +4,12 @@
 
 import time
 from ..exceptions import *
-from ..common import raise_exception, MULTISPHERE_ID, json
+from ..common import raise_exception, MULTISPHERE_ID, json_type, business_logic
 
 
 class Polymatica57():
     """ Реализация методов, заточенная под Полиматику версии 5.7 """
-    def __init__(self, base_bs):
+    def __init__(self, base_bs: business_logic):
         self.base_bs = base_bs
         self._raise_exception = raise_exception(self.base_bs)
 
@@ -28,7 +28,7 @@ class Polymatica57():
         )
         return result
 
-    def get_scripts_description_list(self) -> json:
+    def get_scripts_description_list(self) -> json_type:
         """
         Получить описание всех сценариев.
         :return: (json) информация по каждому сценарию в формате JSON (список словарей).
@@ -160,14 +160,20 @@ class Polymatica57():
         self.base_bs.active_layer_id = layer_uuid
         layer_settings = self.base_bs.execute_manager_command(
             command_name="user_layer", state="get_layer", layer_id=layer_uuid)
-        layer_modules = self.base_bs.h.parse_result(
+        module_descs = self.base_bs.h.parse_result(
             result=layer_settings, key="layer", nested_key="module_descs") or list()
-        for module in layer_modules:
-            if module.get('type_id') == MULTISPHERE_ID:
-                self.base_bs._set_multisphere_module_id(module.get('uuid'))
-                self.base_bs.cube_id = module.get('cube_id')
-                break
+        if not module_descs:
+            self.base_bs._set_multisphere_module_id(str())
+            self.base_bs.cube_id = str()
+        else:
+            for module in module_descs:
+                # берём первую по счёту мультисферу
+                if module.get('type_id') == MULTISPHERE_ID:
+                    self.base_bs._set_multisphere_module_id(module.get('uuid', str()))
+                    self.base_bs.cube_id = module.get('cube_id', str())
+                    break
 
         # 11. Обновление числа строк активной мультисферы
         if self.base_bs.multisphere_module_id:
             self.base_bs.update_total_row()
+        self.base_bs.func_name = 'run_scenario'
